@@ -485,7 +485,7 @@ void TimelineModel::updateInformationElements()
             continue;
         }
 
-        if ((*it).isCanceled()) {
+        if ((*it).isCanceled() || (*it).isInformational()) {
             ++it;
             continue;
         }
@@ -549,7 +549,7 @@ void TimelineModel::updateWeatherElements()
 
             // if we are in an ongoing location change, start afterwards
             const auto endDt = (*it).endDateTime();
-            if (endDt.isValid() && date < endDt) {
+            if ((*it).isLocationChange() && endDt.isValid() && date < endDt) {
                 date = endDt;
             }
         }
@@ -612,8 +612,6 @@ void TimelineModel::updateWeatherElements()
             m_weatherMgr->monitorLocation(geo.latitude(), geo.longitude());
             fc = m_weatherMgr->forecast(geo.latitude(), geo.longitude(), date, endTime);
         }
-        geo = newGeo;
-        label = newLabel;
 
         // updated or new data
         if (fc.isValid()) {
@@ -627,6 +625,8 @@ void TimelineModel::updateWeatherElements()
             endRemoveRows();
         }
 
+        geo = newGeo;
+        label = newLabel;
         date = nextStartTime.addSecs(1);
         ++it;
     }
