@@ -492,12 +492,13 @@ bool TransferManager::isNotInTripGroup(const QString &resId) const
 }
 
 // default transfer anchor deltas (in minutes)
-enum { FlightDelta, TrainDelta, BusDelta, BoatDelta, FallbackDelta };
+enum { FlightDelta, TrainDelta, BusDelta, BoatDelta, RestaurantDelta, FallbackDelta };
 static constexpr const int default_deltas[][2] = {
     { 90, 30 }, // Flight
     { 20, 10 }, // Train
     { 15, 10 }, // Bus
     { 60, 30 }, // Boat/Ferry
+    {  5,  5 }, // Restaurant
     { 30, 15 }, // anything else
 };
 
@@ -516,6 +517,8 @@ void TransferManager::determineAnchorDeltaDefault(Transfer &transfer, const QVar
         delta = default_deltas[BusDelta][transfer.alignment()];
     } else if (JsonLd::isA<BoatReservation>(res)) {
         delta = default_deltas[BoatDelta][transfer.alignment()];
+    } else if (JsonLd::isA<FoodEstablishmentReservation>(res)) {
+        delta = default_deltas[RestaurantDelta][transfer.alignment()];
     } else {
         delta = default_deltas[FallbackDelta][transfer.alignment()];
     }
@@ -601,6 +604,9 @@ FavoriteLocation TransferManager::pickFavorite(const QVariant &anchoredLoc, cons
 
     // pick the first location within a 50km distance
     const auto anchordCoord = LocationUtil::geo(anchoredLoc);
+    if (!anchordCoord.isValid()) {
+        return {};
+    }
     const auto it = std::find_if(favLocs.begin(), favLocs.end(), [&anchordCoord](const auto &fav) {
         const auto d = LocationUtil::distance(anchordCoord.latitude(), anchordCoord.longitude(), fav.latitude(), fav.longitude());
         return d < 50'000;
